/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.    
 */
package org.fabric3.loader.composite;

import javax.xml.namespace.QName;

import org.fabric3.spi.loader.LoaderException;

/**
 * Exception that indicates that the implementation of a component was not valid.
 *
 * @version $Rev: 2163 $ $Date: 2007-12-02 21:09:50 +0000 (Sun, 02 Dec 2007) $
 */
public class InvalidImplementationException extends CompositeLoaderException {
    private final String componentName;

    public InvalidImplementationException(String componentName, LoaderException cause) {
        super(cause);
        this.componentName = componentName;
    }

    public String getComponentName() {
        return componentName;
    }

    public String getMessage() {
        return "Invalid implementation for component " + componentName;
    }
}